/*
 * ugcitest.c  Version 0.2
 *
 * Copyright (c) 1999 Adam Wiggins
 */

/*
 * This program can be used to test all the features of the Linux
 * HAPP USB UGCI API.  It is mainly intended as an example of how
 * to write your own application using the UGCI device.
 * Naturally you'll need the driver installed and /dev/usbugci
 * set up properly for this to work: please see the INSTALL file
 * for information on how to do this.
 */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <linux/ugci.h>

int main()
{
	struct ugci_state state, old_state;
	long tx = 0, ty = 0;

	int fd = open("/dev/usbugci", O_RDONLY);
	if (fd < 0) {
		fprintf(stderr, "unable to open /dev/usbugci for reading\n");
		return -1;
	}

	memset(&old_state, 42, sizeof(struct ugci_state));

	while (1)
	{
		read(fd, &state, sizeof(struct ugci_state));

		if (state.buttons != old_state.buttons ||
			state.coin_count[0] != old_state.coin_count[0] ||
			state.coin_count[1] != old_state.coin_count[1] ||
			state.tdx != old_state.tdx || state.tdy != old_state.tdy)
		{
			tx += state.tdx;
			ty += state.tdy;
#if 0
			printf("                                                                             \r");
			printf("%04x = Coin: %d %d Start: %d (%d/%d) %d (%d/%d) Buttons: %d (%d/%d) Trackball: %ld %ld\r",
					state.buttons, state.coin_count[0], state.coin_count[1],
					(state.buttons & (1 << BTN_START_1)) ? 1 : 0,
					state.pressed_count[BTN_START_1], state.released_count[BTN_START_1],
					(state.buttons & (1 << BTN_START_2)) ? 1 : 0,
					state.pressed_count[BTN_START_2], state.released_count[BTN_START_2],
					(state.buttons & (1 << BTN_1)) ? 1 : 0,
					state.pressed_count[BTN_1], state.released_count[BTN_1],
					tx, ty);
#endif
			printf("%d, %d\n", state.tdx, state.tdy);
			fflush(stdout);

			memcpy(&old_state, &state, sizeof(struct ugci_state));
		}
	}

	close(fd);
	return 0;
}

